
# Slot: has part


holds between wholes and their parts (material entities or processes)

URI: [biolink:has_part](https://w3id.org/biolink/vocab/has_part)

## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [overlaps](overlaps.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)
